//////////////////////////////////////////////////////////////////////////////////
// Module Name:    Freq_Divider 
// Target Devices: EP4CE6E22C8N
// Tool versions:  Quartus II 14.1
// Description:  This module generates a 1 Hz outpout clock displayed on one LED(LD1) on EP4CE6 Mini Board;

//////////////////////////////////////////////////////////////////////////////////
module Freq_Divider(
	input  clk_50M,   // 50 Mhz input clock
	input  reset,	   // reset input
	output clock_out  // 1 Hz output clock
	);

reg clock_div;
reg[24:0] count; // count register

parameter CNT_MAX_1HZ = 25'b1_0111_1101_0111_1000_0100_0000; // 25,000,000 counts

always@( posedge clk_50M )
begin
	if( reset == 1 || count == CNT_MAX_1HZ ) // The counter register will be cleared when reset signal asserts 
		count <= 0;									  // or reaches the max count value for 1Hz output
	else
		count <= count + 1'b1;
end
		
		
always@( posedge clk_50M )
begin
	if( reset == 1  )
		clock_div <= 0;
	else
	begin
		if( count == CNT_MAX_1HZ )
			clock_div <= ~clock_div; //bit toggle
	end
end

assign clock_out = clock_div;

endmodule



